@@ -24,8 +24,10 @@ from .filters import (
     pattern_match,
     years_match,
 )
+from .netcdf import inject_nc_methods
 from .offsets import generate_range, to_offset
-from .pyam_compat import Axes, IamDataFrame, LongDatetimeIamDataFrame
+from .plotting import inject_plotting_methods
+from .pyam_compat import IamDataFrame, LongDatetimeIamDataFrame
 from .time import TimePoints, TimeseriesConverter
 from .units import UnitConverter
 
@@ -201,6 +203,7 @@ def _format_wide_data(df):
     df = df.drop(REQUIRED_COLS + extra_cols, axis="columns").T
     df.index.name = "time"
     meta = orig[REQUIRED_COLS + extra_cols].set_index(df.columns)
+    meta.columns.name = None
 
     return df, meta
 
@@ -432,11 +435,15 @@ class ScmDataFrame:  # pylint: disable=too-many-public-methods
         return self.set_meta(value, name=key)
 
     @property
-    def time_points(self) -> np.ndarray:
+    def time_points(self):
         """
         Time points of the data
+
+        Returns
+        -------
+        :obj:`scmdata.time.TimePoints`
         """
-        return self._time_points.values
+        return self._time_points
 
     def timeseries(self, meta: Optional[List[str]] = None) -> pd.DataFrame:
         """
@@ -911,7 +918,7 @@ class ScmDataFrame:  # pylint: disable=too-many-public-methods
         old_data = res._data
         res._data = pd.DataFrame(index=timeseries_index, columns=res._data.columns)
 
-        time_points = self.time_points
+        time_points = self.time_points.values
 
         timeseries_converter = TimeseriesConverter(
             time_points,
@@ -1336,55 +1343,52 @@ class ScmDataFrame:  # pylint: disable=too-many-public-methods
 
         return LongDatetimeIamDataFrame(self.timeseries())
 
-    def to_csv(self, path: str, **kwargs: Any) -> None:
+    def to_csv(self, fname: str, **kwargs: Any) -> None:
         """
         Write timeseries data to a csv file
 
         Parameters
         ----------
-        path
+        fname
             Path to write the file into
         """
-        self.to_iamdataframe().to_csv(path, **kwargs)
+        self.timeseries().reset_index().to_csv(fname, **kwargs)
 
-    def line_plot(self, x: str = "time", y: str = "value", **kwargs: Any) -> Axes:
+    def groupby(self, *group):
         """
-        Plot a line chart.
+        Group the object by unique metadata
 
-        See :func:`pyam.IamDataFrame.line_plot` for more information.
-        """
-        return self.to_iamdataframe().line_plot(x, y, **kwargs)  # pragma: no cover
+        Enables iteration over groups of data. For example, to iterate over each scenario in the object.
 
-    def scatter(self, x: str, y: str, **kwargs: Any) -> Axes:
-        """
-        Plot a scatter chart using metadata columns.
+        This implementation is much simpler compared to :class`ScmRun` and only allows for iteration over groups.
 
-        See :func:`pyam.plotting.scatter` for details.
-        """
-        self.to_iamdataframe().scatter(x, y, **kwargs)  # pragma: no cover
+        Parameters
+        ----------
+        group: str
+            Columns to group by
+            This implementation only handles a single group at a time
 
-    def region_plot(self, **kwargs: Any) -> Axes:
-        """
-        Plot regional data for a single model, scenario, variable, and year.
+        Returns
+        -------
+        :obj`RunGroupBy`
+            See the documentation for :class`RunGroupBy` for more information
 
-        See :class:`pyam.plotting.region_plot` for details.
-        """
-        return self.to_iamdataframe().region_plot(**kwargs)  # pragma: no cover
+        Raises
+        ------
+        NotImplementedError
+            If more than one group is passed
 
-    def pivot_table(
-        self,
-        index: Union[str, List[str]],
-        columns: Union[str, List[str]],
-        **kwargs: Any
-    ) -> pd.DataFrame:
         """
-        Pivot the underlying data series.
+        res = []
+        if len(group) != 1:
+            raise NotImplementedError(
+                "ScmDataFrame.groupby only handles a single group"
+            )
+        group = group[0]
+        for v in self.meta[group].unique():
+            res.append(self.filter(**{group: v}))
 
-        See :func:`pyam.core.IamDataFrame.pivot_table` for details.
-        """
-        return self.to_iamdataframe().pivot_table(
-            index, columns, **kwargs
-        )  # pragma: no cover
+        return res
 
 
 def df_append(
@@ -1512,3 +1516,7 @@ def _handle_potential_duplicates_in_append(data, duplicate_msg):
         return data
 
     raise ValueError("Unrecognised value for duplicate_msg")
+
+
+inject_nc_methods(ScmDataFrame)
+inject_plotting_methods(ScmDataFrame)
